@@ -251,71 +251,24 @@ reg_entry* reg_entry_open(reg_registry* reg, char* name, char* version,
 int reg_entry_delete(reg_entry* entry, reg_error* errPtr) {
     reg_registry* reg = entry->reg;
     int result = 0;
+
+    errPtr->code = REG_SQLITE_ERROR;
+    errPtr->description = "an unknown sqlite error occurred";
+    errPtr->free = NULL;
+
     sqlite3_stmt* ports = NULL;
-    sqlite3_stmt* files = NULL;
-    sqlite3_stmt* dependencies = NULL;
-    sqlite3_stmt* portgroups = NULL;
+    /* Relies on cascading to delete associated files, dependencies,
+       and portgroups. */
     char* ports_query = "DELETE FROM registry.ports WHERE id=?";
-    char* files_query = "DELETE FROM registry.files WHERE id=?";
-    char* dependencies_query = "DELETE FROM registry.dependencies WHERE id=?";
-    char* portgroups_query = "DELETE FROM registry.portgroups WHERE id=?";
     if ((sqlite3_prepare_v2(reg->db, ports_query, -1, &ports, NULL) == SQLITE_OK)
-            && (sqlite3_bind_int64(ports, 1, entry->id) == SQLITE_OK)
-            && (sqlite3_prepare_v2(reg->db, files_query, -1, &files, NULL)
-                == SQLITE_OK)
-            && (sqlite3_bind_int64(files, 1, entry->id) == SQLITE_OK)
-            && (sqlite3_prepare_v2(reg->db, dependencies_query, -1, &dependencies,
-                    NULL) == SQLITE_OK)
-            && (sqlite3_bind_int64(dependencies, 1, entry->id) == SQLITE_OK)
-            && (sqlite3_prepare_v2(reg->db, portgroups_query, -1, &portgroups,
-                    NULL) == SQLITE_OK)
-            && (sqlite3_bind_int64(portgroups, 1, entry->id) == SQLITE_OK)) {
+            && (sqlite3_bind_int64(ports, 1, entry->id) == SQLITE_OK)) {
         int r;
         do {
             r = sqlite3_step(ports);
             switch (r) {
                 case SQLITE_DONE:
                     if (sqlite3_changes(reg->db) > 0) {
-                        do {
-                            r = sqlite3_step(files);
-                            switch (r) {
-                                case SQLITE_DONE:
-                                    do {
-                                        r = sqlite3_step(dependencies);
-                                        switch (r) {
-                                            case SQLITE_DONE:
-                                                do {
-                                                    r = sqlite3_step(portgroups);
-                                                    switch (r) {
-                                                        case SQLITE_DONE:
-                                                            result = 1;
-                                                            break;
-                                                        case SQLITE_BUSY:
-                                                            break;
-                                                        case SQLITE_ERROR:
-                                                            reg_sqlite_error(reg->db,
-                                                                    errPtr, NULL);
-                                                            break;
-                                                    }
-                                                } while (r == SQLITE_BUSY);
-                                                break;
-                                            case SQLITE_BUSY:
-                                                break;
-                                            case SQLITE_ERROR:
-                                                reg_sqlite_error(reg->db,
-                                                        errPtr, NULL);
-                                                break;
-                                        }
-                                    } while (r == SQLITE_BUSY);
-                                    break;
-                                case SQLITE_BUSY:
-                                    break;
-                                case SQLITE_ERROR:
-                                    reg_sqlite_error(reg->db, errPtr, NULL);
-                                    break;
-                            }
-                        } while (r == SQLITE_BUSY);
-                        break;
+                        result = 1;
                     } else {
                         errPtr->code = REG_INVALID;
                         errPtr->description = "an invalid entry was passed";
@@ -325,6 +278,7 @@ int reg_entry_delete(reg_entry* entry, reg_error* errPtr) {
                 case SQLITE_BUSY:
                     break;
                 case SQLITE_ERROR:
+                default:
                     reg_sqlite_error(reg->db, errPtr, NULL);
                     break;
             }
@@ -335,15 +289,6 @@ int reg_entry_delete(reg_entry* entry, reg_error* errPtr) {
     if (ports) {
         sqlite3_finalize(ports);
     }
-    if (files) {
-        sqlite3_finalize(files);
-    }
-    if (dependencies) {
-        sqlite3_finalize(dependencies);
-    }
-    if (portgroups) {
-        sqlite3_finalize(portgroups);
-    }
     return result;
 }
 
@@ -415,6 +360,7 @@ int reg_entry_search(reg_registry* reg, const char** keys, const char** vals,
         /* get the strategy */
         op = reg_strategy_op(strategies[i], errPtr);
         if (op == NULL) {
+            free(query);
             return -1;
         }
         char* cond = sqlite3_mprintf(op, keys[i], vals[i]);
@@ -864,7 +810,7 @@ int reg_entry_map(reg_entry* entry, char** files, int file_count,
 }
 
 /**
- * Unaps files from the given port in the filemap. The files must be owned by
+ * Unmaps files from the given port in the filemap. The files must be owned by
  * the given entry.
  *
  * @param [in] entry      the entry to unmap the files from
@@ -895,8 +841,8 @@ int reg_entry_unmap(reg_entry* entry, char** files, int file_count,
                     switch (r) {
                         case SQLITE_DONE:
                             if (sqlite3_changes(reg->db) == 0) {
-                                reg_throw(errPtr, REG_INVALID, "this entry "
-                                        "does not own the given file");
+                                reg_throw(errPtr, REG_INVALID, "%s is not "
+                                        "owned by this entry", files[i]);
                                 result = 0;
                             } else {
                                 sqlite3_reset(stmt);
@@ -942,9 +888,9 @@ int reg_entry_imagefiles(reg_entry* entry, char*** files, reg_error* errPtr) {
     char* query = "SELECT path FROM registry.files WHERE id=? ORDER BY path";
     if ((sqlite3_prepare_v2(reg->db, query, -1, &stmt, NULL) == SQLITE_OK)
             && (sqlite3_bind_int64(stmt, 1, entry->id) == SQLITE_OK)) {
-        char** result = malloc(10*sizeof(char*));
+        char** result = malloc(REG_RESULT_INITIAL_SPACE*sizeof(char*));
         int result_count = 0;
-        int result_space = 10;
+        int result_space = REG_RESULT_INITIAL_SPACE;
         int r;
         const char *text;
         char* element;
@@ -1010,9 +956,9 @@ int reg_entry_files(reg_entry* entry, char*** files, reg_error* errPtr) {
         "AND active ORDER BY actual_path";
     if ((sqlite3_prepare_v2(reg->db, query, -1, &stmt, NULL) == SQLITE_OK)
             && (sqlite3_bind_int64(stmt, 1, entry->id) == SQLITE_OK)) {
-        char** result = malloc(10*sizeof(char*));
+        char** result = malloc(REG_RESULT_INITIAL_SPACE*sizeof(char*));
         int result_count = 0;
-        int result_space = 10;
+        int result_space = REG_RESULT_INITIAL_SPACE;
         int r;
         const char *text;
         char* element;
@@ -1137,6 +1083,7 @@ int reg_entry_activate(reg_entry* entry, char** files, char** as_files,
                                         case SQLITE_BUSY:
                                             break;
                                         case SQLITE_ERROR:
+                                        default:
                                             reg_sqlite_error(reg->db, errPtr,
                                                     update_query);
                                             result = 0;
@@ -1147,6 +1094,7 @@ int reg_entry_activate(reg_entry* entry, char** files, char** as_files,
                             case SQLITE_BUSY:
                                 break;
                             case SQLITE_ERROR:
+                            default:
                                 reg_sqlite_error(reg->db, errPtr, select_query);
                                 result = 0;
                                 break;
@@ -1211,8 +1159,8 @@ int reg_entry_deactivate(reg_entry* entry, char** files, int file_count,
                     switch (r) {
                         case SQLITE_DONE:
                             if (sqlite3_changes(reg->db) == 0) {
-                                reg_throw(errPtr, REG_INVALID, "this entry "
-                                        "does not own the given file");
+                                reg_throw(errPtr, REG_INVALID, "%s is not "
+                                        "owned by this entry", files[i]);
                                 result = 0;
                             } else {
                                 sqlite3_reset(stmt);
